﻿import QtQuick 1.1
import com.nokia.meego 1.0
import QtMobility.feedback 1.1

Page {
    tools: commonTools
    orientationLock: PageOrientation.LockPortrait
    property alias model: ussdListItem.model
    property alias count: ussdListItem.count
    property alias currentIndex: ussdListItem.selectedIndex
    property alias list: ussdListItem.list
    Rectangle {
        color: "black"
        anchors.fill:parent

        PinchArea {
            id: dndArea
            anchors.fill: parent

            property int draggedIndex: 0

            onPinchStarted: {
                draggedIndex = list.indexAt(list.contentX+pinch.startPoint2.x, list.contentY+pinch.startPoint2.y);
            }

            onPinchUpdated: {
                var targetIndex = list.indexAt(list.contentX+pinch.point2.x, list.contentY+pinch.point2.y);
                if (draggedIndex >= 0 && targetIndex >= 0 && draggedIndex !== targetIndex) {
                    moveVibro.start();
                    model.move(draggedIndex,targetIndex,1);
                    ussdengine.move(draggedIndex,targetIndex);
                    draggedIndex = targetIndex;
                }

            }

            HapticsEffect {
                id: moveVibro
                attackIntensity: 0.0
                attackTime: 50
                intensity: 0.8
                duration: 50
                fadeTime: 50
                fadeIntensity: 0.0        }
        }

        UssdList {
            id: ussdListItem
        }
    }

    function sendUSSD() {
        if ((mainPage.count > 0) & (mainPage.currentIndex >= 0)) {
            msgBox.text = qsTr("Sending request...")
            msgBox.visible = true
            ussdListItem.visible = false
            ussdengine.sendUssd(mainPage.currentIndex);
        }

    }

    ToolBarLayout {
        id: commonTools
        visible: true
        ToolIcon {
            platformIconId: "toolbar-back"
            anchors.left: (parent === undefined) ? undefined : parent.left
            onClicked: Qt.quit()
        }




        ToolIcon {
            platformIconId: "toolbar-add"
            onClicked: {
                addPage.editingIndex = -1
                appWindow.pageStack.push(addPage)
            }
        }

        ToolIcon {
            platformIconId: "toolbar-edit"
            visible: (mainPage.count > 0) & (mainPage.currentIndex >= 0)
            onClicked: {
                addPage.name = mainPage.model.get(currentIndex).name
                addPage.ussd = mainPage.model.get(currentIndex).ussd
                addPage.editingIndex = currentIndex
                appWindow.pageStack.push(addPage)
            }
        }

        ToolIcon {
            platformIconId: "toolbar-view-menu"
            onClicked: (myMenu.status === DialogStatus.Closed) ? myMenu.open() : myMenu.close()
        }
    }



    Rectangle {
        id: msgBox
        property alias text: msgText.text
        visible: false
        anchors.centerIn: parent
        radius: 10
        color:"black"
        width:parent.width-50
        height:200
        border {
            color: "white"
            width: 2
        }
        Text {
            id: msgText
            horizontalAlignment: Text.AlignHCenter
            width: parent.width-10
            text: ""
            font.pixelSize: 30
            smooth: true
            color:"white"

        }
        Button {
            id: msgButton
            text: "Ok"
            anchors.top: msgText.bottom
            anchors.topMargin: 20
            anchors.horizontalCenter: parent.horizontalCenter
            visible: false
            onClicked: {
                msgBox.visible = false
                msgButton.visible = false
                ussdListItem.visible = true

            }
        }

        Connections {
            target: ussdengine
            onUssdCommandCompleted: {
                msgBox.visible = false
                msgButton.visible = false
                ussdListItem.visible = true

            }
            onUssdCommandError: {
                msgButton.visible = true
                msgBox.text = qsTr("Error!")

            }
        }
    }

}


